pub trait Tuple: Seal { }Expand description
A specialized const-list for emulating varaidic generics
To overload what elements can go in this tuple, please use the
TupleElem trait
This is a sealed trait that is not meant to be extended
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".